package com.jsowell.thirdparty.service;

import com.jsowell.pile.vo.ThirdPartySecretInfoVO;
import com.jsowell.pile.vo.base.StationInfoVO;
import com.jsowell.thirdparty.domain.ThirdpartySecretInfo;

import java.util.List;

/**
 * 对接三方平台配置Service接口
 *
 * @author jsowell
 * @date 2024-04-18
 */
public interface ThirdpartySecretInfoService {
    /**
     * 查询对接三方平台配置
     *
     * @param id 对接三方平台配置主键
     * @return 对接三方平台配置
     */
    public ThirdpartySecretInfo selectThirdpartySecretInfoById(Long id);

    /**
     * 查询对接三方平台配置列表
     *
     * @param thirdpartySecretInfo 对接三方平台配置
     * @return 对接三方平台配置集合
     */
    public List<ThirdpartySecretInfo> selectThirdpartySecretInfoList(ThirdpartySecretInfo thirdpartySecretInfo);

    /**
     * 新增对接三方平台配置
     *
     * @param thirdpartySecretInfo 对接三方平台配置
     * @return 结果
     */
    public int insertThirdpartySecretInfo(ThirdpartySecretInfo thirdpartySecretInfo);

    /**
     * 修改对接三方平台配置
     *
     * @param thirdpartySecretInfo 对接三方平台配置
     * @return 结果
     */
    public int updateThirdpartySecretInfo(ThirdpartySecretInfo thirdpartySecretInfo);

    /**
     * 批量删除对接三方平台配置
     *
     * @param ids 需要删除的对接三方平台配置主键集合
     * @return 结果
     */
    public int deleteThirdpartySecretInfoByIds(Long[] ids);

    /**
     * 删除对接三方平台配置信息
     *
     * @param id 对接三方平台配置主键
     * @return 结果
     */
    public int deleteThirdpartySecretInfoById(Long id);

    /**
     * 通过组织结构代码，查询平台密钥配置信息
     * @param theirOperatorId 组织结构代码
     * @return
     */
    ThirdPartySecretInfoVO queryByOperatorId(String theirOperatorId);

    /**
     * 通过第三方平台类型，查询平台密钥配置信息
     * @param thirdPlatformType 第三方平台类型, 参见{@link com.jsowell.common.enums.thirdparty.ThirdPlatformTypeEnum}
     * @return
     */
    ThirdPartySecretInfoVO queryByThirdPlatformType(String thirdPlatformType);

    /**
     * 查询站点对接第三方平台信息列表
     * @param stationId 站点id
     * @return
     */
    List<ThirdPartySecretInfoVO> queryStationToPlatformList(String stationId);

    /**
     * 根据第三方平台类型查询对接第三方平台的站点列表
     * @param thirdPlatformType
     * @return
     */
    List<StationInfoVO> selectStationList(String thirdPlatformType);
}
